@@ -138,10 +138,10 @@
 ;; If there are no changes to existing files, no update occurs.
 (define* (gen-c99cx-files #:optional (path "."))
   (define (mdir file) (mach-dir path file))
-  (write-lalr-actions c99cx-mach (mdir "c99cxact.scm.new") #:prefix "c99cx-")
-  (write-lalr-tables c99cx-mach (mdir "c99cxtab.scm.new") #:prefix "c99cx-")
-  (let ((a (move-if-changed (mdir "c99cxact.scm.new") (mdir "c99cxact.scm")))
-	(b (move-if-changed (mdir "c99cxtab.scm.new") (mdir "c99cxtab.scm"))))
+  (write-lalr-actions c99cx-mach (mdir "c99cx-act.scm.new") #:prefix "c99cx-")
+  (write-lalr-tables c99cx-mach (mdir "c99cx-tab.scm.new") #:prefix "c99cx-")
+  (let ((a (move-if-changed (mdir "c99cx-act.scm.new") (mdir "c99cx-act.scm")))
+	(b (move-if-changed (mdir "c99cx-tab.scm.new") (mdir "c99cx-tab.scm"))))
     (or a b)))
 
 ;; --- last line ---
