@@ -1,6 +1,6 @@
 ;;; nyacc/lang/c99/util.scm - C parser utilities
 
-;; Copyright (C) 2015-2018 Matthew R. Wette
+;; Copyright (C) 2015-2019 Matthew R. Wette
 ;;
 ;; This library is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU Lesser General Public
@@ -20,10 +20,11 @@
 (define-module (nyacc lang c99 util)
   #:export (c99-def-help
 	    c99-std-help
-	    get-gcc-cpp-defs get-gcc-inc-dirs 
+	    get-gcc-cpp-defs
+	    get-gcc-inc-dirs 
 	    remove-inc-trees
 	    merge-inc-trees!
-	    move-attributes attrl->attrs attrs->attrl
+	    move-attributes attrl->attrs attrs->attrl extract-attr
 	    elifify)
   #:use-module (nyacc lang util)
   #:use-module (nyacc lang sx-util)
@@ -135,17 +136,17 @@
 (define* (get-gcc-inc-dirs #:optional (args '()) #:key CC)
   (let ((ip (open-input-pipe (string-append
 			      (resolve-CC CC) " -E -Wp,-v - </dev/null 2>&1"))))
-    (let iter ((dirs '()) (grab #f) (line (read-line ip 'trim)))
+    (let loop ((dirs '()) (grab #f) (line (read-line ip 'trim)))
       (cond
        ((eof-object? line) dirs)
        ((string=? line "#include <...> search starts here:")
-	(iter dirs #t (read-line ip 'trim)))
+	(loop dirs #t (read-line ip 'trim)))
        ((string=? line "End of search list.") dirs)
        (grab
-	(iter (cons (string-trim-both line) dirs)
+	(loop (cons (string-trim-both line) dirs)
 	      grab (read-line ip 'trim)))
        (else
-	(iter dirs grab (read-line ip 'trim)))))))
+	(loop dirs grab (read-line ip 'trim)))))))
 
 ;; @deffn {Procedure} remove-inc-trees tree
 ;; Remove the trees included with cpp-include statements.
@@ -156,16 +157,16 @@
 ;; @end deffn
 (define (remove-inc-trees tree)
   (if (not (eqv? 'trans-unit (car tree))) (error "expecting c-tree"))
-  (let iter ((rslt (make-tl 'trans-unit))
+  (let loop ((rslt (make-tl 'trans-unit))
 	     ;;(head '(trans-unit)) (tail (cdr tree))
 	     (tree (cdr tree)))
     (cond
      ((null? tree) (tl->list rslt))
      ((and (eqv? 'cpp-stmt (car (car tree)))
 	   (eqv? 'include (caadr (car tree))))
-      (iter (tl-append rslt `(cpp-stmt (include ,(cadadr (car tree)))))
+      (loop (tl-append rslt `(cpp-stmt (include ,(cadadr (car tree)))))
 	    (cdr tree)))
-     (else (iter (tl-append rslt (car tree)) (cdr tree))))))
+     (else (loop (tl-append rslt (car tree)) (cdr tree))))))
 
 ;; @deffn {Procedure} merge-inc-trees tree
 ;; Remove the trees included with cpp-include statements.
@@ -176,13 +177,13 @@
 ;; @end deffn
 #;(define (Xmerge-inc-trees tree)
   (if (not (eqv? 'trans-unit (car tree))) (error "expecting c-tree"))
-  (let iter ((rslt (make-tl 'trans-unit))
+  (let loop ((rslt (make-tl 'trans-unit))
 	     (tree (cdr tree)))
     (cond
      ((null? tree) (tl->list rslt))
      ((and (eqv? 'cpp-stmt (caar tree)) (eqv? 'include (cadar tree)))
-      (iter (tl-extend rslt (cdr (merge-inc-trees (cdddar tree)))) (cdr tree)))
-     (else (iter (tl-append rslt (car tree)) (cdr tree))))))
+      (loop (tl-extend rslt (cdr (merge-inc-trees (cdddar tree)))) (cdr tree)))
+     (else (loop (tl-append rslt (car tree)) (cdr tree))))))
 
 
 ;; @deffn {Procedure} merge-inc-trees! tree => tree
@@ -206,7 +207,7 @@
      ((null? (cdr tree)) (error "null c99-tree"))
      (else
       (let ((fp tree))			; first pair
-	(let iter ((lp tree)		; last pair
+	(let loop ((lp tree)		; last pair
 		   (np (cdr tree)))	; next pair
 	  (cond
 	   ((null? np) (cons (cdr fp) lp))
@@ -219,10 +220,10 @@
 		       ((pair? rest))
 		       (span (find-span (car rest))))
 		      (set-cdr! lp (car span))
-		      (iter (cdr span) (cdr np))))
+		      (loop (cdr span) (cdr np))))
 	   (else
 	    (set-cdr! lp np)
-	    (iter np (cdr np)))))))))
+	    (loop np (cdr np)))))))))
 
   ;; Use cons to generate a new reference:
   ;; (cons (car tree) (car (find-span tree)))
@@ -257,7 +258,6 @@
       (loop (append (sx-tail (car tail0)) atl) tail1 (cdr tail0)))
      (else
       (loop atl (cons (car tail0) tail1) (cdr tail0))))))
-(export extract-attr)
 
 ;; (attribute-list (attribute (ident "__packed__")) ...)
 ;;  =>
