@@ -56,9 +56,9 @@
   #:use-module (rnrs bytevectors)
   #:use-module ((system foreign) #:prefix ffi:)
   #:use-module (srfi srfi-9)
-  #:version (0 94 0))
+  #:version (0 99 0))
 
-(define *ffi-help-version* "0.94.0")
+(define *ffi-help-version* "0.99.0")
 
 (define (sferr fmt . args) (apply simple-format (current-error-port) fmt args))
 
@@ -585,7 +585,7 @@
 	     ((string? expr) (ffi:string->pointer expr))
 	     ;;((bytestructure? expr)  ...
 	     (else
-	      (display "ffi-help-rt: WARNING: bizzare cast\n")
+	      (display "ffi-help-rt: WARNING: bizarre cast\n")
 	      expr)))
 	   (else expr))))
     (cons r-type r-expr)))
